@@ -14,7 +14,15 @@ extern void feed_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT (feed-marshal.list:2) */
+/* VOID:OBJECT,STRING (feed-marshal.list:2) */
+extern void feed_marshal_VOID__OBJECT_STRING (GClosure     *closure,
+                                              GValue       *return_value,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data);
+
+/* VOID:OBJECT,OBJECT (feed-marshal.list:3) */
 extern void feed_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
