@@ -29,6 +29,7 @@
 #include <libxml/entities.h>
 #include <libxml/HTMLparser.h>
 #include <libxml/xpath.h>
+#include <libxml/xpathInternals.h>
 
 #include "feed-channel.h"
 #include "feed-enclosure.h"
@@ -37,6 +38,7 @@
 #include "feeds-store.h"
 #include "feeds-pool.h"
 #include "feeds-subscriber.h"
+#include "feeds-publisher.h"
 #include "feeds-group.h"
 
 #endif /* __LIBGRSS_H__ */
